==> dogecoin_1.10.0.orig.tar.gz: dogecoin-1.10.0/src/qt/locale/bitcoin_kk_KZ.ts <==
<TS language="kk_KZ" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаңа адрес енгізу</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Жаңа</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Таңдаған адресті тізімнен жою</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Жабу</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Жою</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Үтірмен бөлінген текст (*.csv)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>таңба</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(таңбасыз)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Құпия сөзді енгізу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Жаңа құпия сөзі</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Жаңа құпия сөзді қайта енгізу</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Әмиянді шифрлау</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Бұл операциясы бойынша сіздің әмиянізді қоршаудан шығару үшін әмиянның құпия сөзі керек</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Әмиянізді қоршаудан шығару</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Бұл операциясы бойынша сіздің әмиянізді шифрлап тастау үшін әмиянның құпия сөзі керек</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Әмиянізді шифрлап тастау</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Құпия сөзді өзгерту</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакциялар</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Шығу</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Параметрлері</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Әмиянды жасыру</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Құпия сөзді өзгерту</translation>
    </message>
    <message>
        <source>Dogecoin</source>
        <translation>Биткоин</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Әмиян</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Жіберу</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Алу</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Көмек</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n сағат</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n күн</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n апта</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 немесе %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n жыл</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 қалмады</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ескерту</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңартылған</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Priority:</source>
        <translation>Басымдық</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Шаң</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Растау саны</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Растық</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Басымдық</translation>
    </message>
    <message>
        <source>no</source>
        <translation>жоқ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(таңбасыз)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation>Адрес</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>таңба</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>таңба</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(таңбасыз)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Priority:</source>
        <translation>Басымдық</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Шаң</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(таңбасыз)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>таңба</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Үтірмен бөлінген файл (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Растық</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>таңба</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>Экспорт</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Транзакция өте кішкентай</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Транзакция өте үлкен</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ескерту</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
</context>
</TS>

==> dogecoin_1.14.3.orig.tar.gz: dogecoin-1.14.3/src/qt/locale/bitcoin_kk_KZ.ts <==
<TS language="kk_KZ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Жаңа адрес енгізу</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Жаңа</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Таңдаған адресті тізімнен жою</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Жабу</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Жою</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Құпия сөзді енгізу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Жаңа құпия сөзі</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Жаңа құпия сөзді қайта енгізу</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>DogecoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Транзакциялар</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Шығу</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Параметрлері</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Әмиянды жасыру</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Құпия сөзді өзгерту</translation>
    </message>
    <message>
        <source>Dogecoin</source>
        <translation>Биткоин</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Әмиян</translation>
    </message>
    <message>
        <source>&amp;Such Send</source>
        <translation>Жіберу</translation>
    </message>
    <message>
        <source>&amp;Much Receive</source>
        <translation>Алу</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Көмек</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 қалмады</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ескерту</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Жаңартылған</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Шаң</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Растау саны</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Растық</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>таңба</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Адрес</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>W&amp;allet</source>
        <translation>Әмиян</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 немесе %2</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Информация</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>Саны</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Саны</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Комиссия:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Комиссия алу кейін:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Шаң</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Саны</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>dogecoin-core</name>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Транзакция өте кішкентай</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Транзакция өте үлкен</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ескерту</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>қате</translation>
    </message>
</context>
</TS>
